@@ -30,7 +30,12 @@ from ..utils.singleton import SingletonMeta
 from ..utils.bcolor import Bcolors
 from ..utils.gunicorn_multiprocess import clear_multiproc_dir
 
-from .config import _DEFAULT_BUCKETS, _DEFAULT_LABELS, NAMESPACE, SERVICENAME
+from .config import (
+    _DEFAULT_BUCKETS,
+    _DEFAULT_LABELS,
+    NAMESPACE,
+    SERVICENAME,
+)
 
 
 class PrometheusMiddleware(metaclass=SingletonMeta):
@@ -49,14 +54,14 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
     _DEFAULT_BUCKETS = _DEFAULT_BUCKETS
 
     METRICS_REQUEST_LATENCY_HISTOGRAM = Histogram(
-        "http_request_duration_ht_ms",
+        "http_request_duration_ms_ht",
         "Duration of HTTP requests in ms (Histogram)",
         labelnames=_DEFAULT_LABELS,
         buckets=_DEFAULT_BUCKETS,
     )
 
     METRICS_REQUEST_LATENCY_SUMMARY = Summary(
-        "http_request_duration_summary_ms",
+        "http_request_duration_ms_summary",
         "Duration of HTTP requests in ms (Summary)",
         labelnames=_DEFAULT_LABELS,
     )
@@ -73,7 +78,7 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
         self,
         app,
         namespace: str = None,
-        serviceName: str = None,
+        service_name: str = None,
         app_version: str = None,
         is_multiprocessing: bool = False,
     ):
@@ -84,8 +89,8 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
         :param namespace: can be use to override namespace that read from .env
         :type namespace: str
 
-        :param serviceName: can be use to override serviceName that read from .env
-        :type serviceName: str
+        :param service_name: can be use to override service_name that read from .env
+        :type service_name: str
 
         :param app_version: optional param can be use for track version of the application
         :type app_version: str
@@ -103,8 +108,8 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
 
         if namespace:
             self.namespace = namespace
-        if serviceName:
-            self.service_name = serviceName
+        if service_name:
+            self.service_name = service_name
         self._check_env(self.namespace, self.service_name)
 
     @staticmethod
@@ -128,14 +133,14 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
                     print(warning_msg)
         return list_input
 
-    def _check_env(self, namespace, serviceName):
+    def _check_env(self, namespace, service_name):
         if namespace == "UNDEFINED" or namespace is None:
             print(
-                f"{Bcolors.WARNING}WARNING: env variable : 'namespace' is not found.\nPlease provide SERVICE_NAME_PREFIX in .env file{Bcolors.ENDC}"
+                f"{Bcolors.WARNING}WARNING: env variable : for label 'namespace' is not found.\nPlease provide SERVICE_NAME_PREFIX in .env file{Bcolors.ENDC}"
             )
-        if serviceName == "UNDEFINED" or serviceName is None:
+        if service_name == "UNDEFINED" or service_name is None:
             print(
-                f"{Bcolors.WARNING}WARNING: env variable : 'serviceName' is not found.\nPlease provide SERVICE_NAME in .env file{Bcolors.ENDC}"
+                f"{Bcolors.WARNING}WARNING: env variable : for label 'serviceName' is not found.\nPlease provide SERVICE_NAME in .env file{Bcolors.ENDC}"
             )
 
     def clear_default_metrics(self):
